@@ -12,13 +12,17 @@ Test your method.
 """
 import numpy as np
 from itertools import product
-
-from tqdm import tqdm
-from PIL import Image
 import math
-import matplotlib.pyplot as plt
 
+""" 
+I cutted out the tensorflow 1 part because I use tensorflow 2 and Python 3.8 in my code which are both
+not compatible with tensorflow 1 and the part of the exercise that I had to fill in only relied on numpy. 
+Also the np.clip takes 3 arguments and not 1, so the code didn't work as is. Because of those two reasons 
+I have commented out that part. 
 
+The part that I implemented is basically a average pooling that preserves the image dimensions due to padding
+if stride is 1 and if stride is bigger than 1 it divide the dimensions by this number.  
+"""
 def image_smoother(
     input_image: np.ndarray,
     kernel_height=5,
@@ -82,15 +86,4 @@ def image_smoother(
             # print(input_image)
             # print(gradient_step)
             # input_image = np.clip(input_image - gradient_step)
-    return mean_kernel
-
-
-image = Image.open('data/imagenet_dogs/ILSVRC2012_val_00023440.JPEG')
-x_test = np.asarray(image, dtype=np.float32)
-x_test = x_test[np.newaxis, ...]
-result = image_smoother(x_test)
-result = np.asarray(result, dtype=np.uint8)
-print(x_test.shape)
-print(result.shape)
-plt.imshow(result[0])
-plt.show()
+    return mean_kernel
\ No newline at end of file
